<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AuthenticationWidget</name>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="15"/>
        <source>Username:</source>
        <translation>Nutzername:</translation>
    </message>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="16"/>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
</context>
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="11"/>
        <source>rpm</source>
        <translation>U/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="12"/>
        <location filename="../src/GUI/cadencegraph.h" line="16"/>
        <source>Cadence</source>
        <translation>Trittfrequenz</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Ø</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Durchschnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>CadenceGraphItem</name>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="19"/>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="21"/>
        <source>rpm</source>
        <translation>U/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>Durchschnitt</translation>
    </message>
</context>
<context>
    <name>Data</name>
    <message>
        <location filename="../src/data/data.cpp" line="234"/>
        <source>Supported files</source>
        <translation>Unterstützte Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="235"/>
        <source>CSV files</source>
        <translation>CSV-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="236"/>
        <source>CUP files</source>
        <translation>CUP-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="237"/>
        <source>FIT files</source>
        <translation>FIT-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="238"/>
        <source>GeoJSON files</source>
        <translation>GeoJSON-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="239"/>
        <source>GPI files</source>
        <translation>GPI-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="240"/>
        <source>GPX files</source>
        <translation>GPX-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="241"/>
        <source>IGC files</source>
        <translation>IGC-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="242"/>
        <source>ITN files</source>
        <translation>ITN-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="243"/>
        <source>JPEG images</source>
        <translation>JPEG-Bilder</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="244"/>
        <source>KML files</source>
        <translation>KML-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="245"/>
        <source>LOC files</source>
        <translation>LOC-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="246"/>
        <source>NMEA files</source>
        <translation>NMEA-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="248"/>
        <source>OV2 files</source>
        <translation>OV2-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="249"/>
        <source>OziExplorer files</source>
        <translation>OziExplorer-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="251"/>
        <source>SML files</source>
        <translation>SML-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="252"/>
        <source>TCX files</source>
        <translation>TCX-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="250"/>
        <source>SLF files</source>
        <translation>SLF-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="247"/>
        <source>ONmove files</source>
        <translation>ONmove-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="253"/>
        <source>70mai GPS log files</source>
        <translation>70mai GPS-Logdateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="254"/>
        <source>VKX files</source>
        <translation>VKX-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="255"/>
        <source>VTK files</source>
        <translation>VTK-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="256"/>
        <source>TwoNav files</source>
        <translation>TwoNav-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="257"/>
        <source>GPSDump files</source>
        <translation>GPSDump-Dateien</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="258"/>
        <source>All files</source>
        <translation>Alle Dateien</translation>
    </message>
</context>
<context>
    <name>DirSelectWidget</name>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="18"/>
        <source>System default</source>
        <translation>Systemvorgabe</translation>
    </message>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="40"/>
        <source>Select directory</source>
        <translation>Verzeichnis auswählen</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="39"/>
        <location filename="../src/GUI/elevationgraph.h" line="16"/>
        <source>Elevation</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="181"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="72"/>
        <source>Ascent</source>
        <translation>Steigung</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="59"/>
        <source>Up</source>
        <extracomment>Use an Unicode arrow (U+2197) when there is no abbreviation or extremly short term for &quot;Up&quot; in your language</extracomment>
        <translation>Hinauf</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="63"/>
        <source>Down</source>
        <extracomment>Use an Unicode arrow (U+2198) when there is no abbreviation or extremly short term for &quot;Down&quot; in your language</extracomment>
        <translation>Hinab</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="66"/>
        <source>Max</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="69"/>
        <source>Min</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="74"/>
        <source>Descent</source>
        <translation>Gefälle</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="78"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="184"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="76"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>ElevationGraphItem</name>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="38"/>
        <source>Ascent</source>
        <translation>Steigung</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="40"/>
        <source>Descent</source>
        <translation>Gefälle</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="42"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="44"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="46"/>
        <location filename="../src/GUI/fileselectwidget.cpp" line="51"/>
        <source>Select file</source>
        <translation>Datei auswählen</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="61"/>
        <source>No output file selected.</source>
        <translation>Keine Ausgabedatei ausgewählt.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="71"/>
        <source>%1 is a directory.</source>
        <translation>%1 ist ein Verzeichnis.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="75"/>
        <source>%1 is not writable.</source>
        <translation>%1 ist nicht beschreibbar.</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/GUI/format.cpp" line="54"/>
        <location filename="../src/GUI/format.cpp" line="64"/>
        <location filename="../src/GUI/format.cpp" line="93"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="57"/>
        <location filename="../src/GUI/format.cpp" line="60"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="67"/>
        <location filename="../src/GUI/format.cpp" line="70"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="74"/>
        <location filename="../src/GUI/format.cpp" line="90"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="77"/>
        <location filename="../src/GUI/format.cpp" line="80"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/GUI/gui.cpp" line="978"/>
        <location filename="../src/GUI/gui.cpp" line="996"/>
        <source>Map directory:</source>
        <translation>Kartenverzeichnis:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="980"/>
        <location filename="../src/GUI/gui.cpp" line="998"/>
        <source>POI directory:</source>
        <translation>POI-Verzeichnis:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1019"/>
        <location filename="../src/GUI/gui.cpp" line="1022"/>
        <source>Open file</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1250"/>
        <location filename="../src/GUI/gui.cpp" line="1253"/>
        <source>Open POI file</source>
        <translation>POI-Datei öffnen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="200"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="212"/>
        <location filename="../src/GUI/gui.cpp" line="935"/>
        <location filename="../src/GUI/gui.cpp" line="936"/>
        <source>Keyboard controls</source>
        <translation>Tastaturkürzel</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="254"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="261"/>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="823"/>
        <source>Show</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="813"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="303"/>
        <source>Overlap POIs</source>
        <translation>POIs überlappen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="313"/>
        <source>Show POI labels</source>
        <translation>POI-Labels anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="319"/>
        <source>Show POIs</source>
        <translation>POIs anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="331"/>
        <source>Show map</source>
        <translation>Karte anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="348"/>
        <source>Clear tile cache</source>
        <translation>Kachel-Cache bereinigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="222"/>
        <source>Open...</source>
        <translation>Öffnen …</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="208"/>
        <location filename="../src/GUI/gui.cpp" line="975"/>
        <location filename="../src/GUI/gui.cpp" line="993"/>
        <source>Paths</source>
        <translation>Pfade</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="229"/>
        <source>Open directory...</source>
        <translation>Verzeichnis öffnen …</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="247"/>
        <source>Export to PNG...</source>
        <translation>Als PNG exportieren …</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="267"/>
        <source>Statistics...</source>
        <translation>Statistiken …</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="277"/>
        <source>Clear list</source>
        <translation>Liste leeren</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="289"/>
        <source>Load POI file...</source>
        <translation>POI-Datei laden …</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="293"/>
        <source>Select all files</source>
        <translation>Alle Dateien wählen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="298"/>
        <source>Unselect all files</source>
        <translation>Alle Dateien abwählen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="308"/>
        <source>Show POI icons</source>
        <translation>POI-Symbole anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="340"/>
        <source>Load map...</source>
        <translation>Karte laden …</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="345"/>
        <source>Load map directory...</source>
        <translation>Kartenverzeichnis laden ...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="353"/>
        <location filename="../src/GUI/gui.cpp" line="358"/>
        <location filename="../src/GUI/gui.cpp" line="954"/>
        <source>Next map</source>
        <translation>Nächste Karte</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="363"/>
        <source>Show cursor coordinates</source>
        <translation>Cursor-Koordinaten anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="371"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="375"/>
        <source>Raster only</source>
        <translation>Nur Raster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="379"/>
        <source>Vector only</source>
        <translation>Nur Vektor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="386"/>
        <source>Show position</source>
        <translation>Position anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="392"/>
        <source>Follow position</source>
        <translation>Position folgen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="397"/>
        <source>Show coordinates</source>
        <translation>Koordinaten anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="403"/>
        <source>Show motion info</source>
        <translation>Bewegungsinfo anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="410"/>
        <source>Show tracks</source>
        <translation>Strecken anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="415"/>
        <source>Show routes</source>
        <translation>Routen anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="420"/>
        <source>Show waypoints</source>
        <translation>Wegpunkte anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="426"/>
        <source>Show areas</source>
        <translation>Flächen anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="431"/>
        <source>Waypoint icons</source>
        <translation>Wegpunkt-Symbole</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="436"/>
        <source>Waypoint labels</source>
        <translation>Wegpunkt-Labels</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="446"/>
        <source>km/mi markers</source>
        <translation>km/mi-Markierungen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="454"/>
        <source>Do not show</source>
        <translation>Nicht anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="458"/>
        <source>Marker only</source>
        <translation>Nur Markierung</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="462"/>
        <source>Date/time</source>
        <translation>Datum/Zeit</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="466"/>
        <source>Coordinates</source>
        <translation>Koordinaten</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="470"/>
        <source>Use styles</source>
        <translation>Stile verwenden</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="488"/>
        <source>Show local DEM tiles</source>
        <translation>Lokale DEM-Kacheln anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="491"/>
        <source>Show hillshading</source>
        <translation>Schummerung anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="499"/>
        <source>Show graphs</source>
        <translation>Graphen anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="520"/>
        <source>Show grid</source>
        <translation>Gitter anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="525"/>
        <source>Show slider info</source>
        <translation>Schieberinfo anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="531"/>
        <source>Show tabs</source>
        <translation>Registerkarten anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="540"/>
        <source>Show toolbars</source>
        <translation>Toolbars anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="547"/>
        <source>Total time</source>
        <translation>Gesamtzeit</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="552"/>
        <location filename="../src/GUI/gui.cpp" line="1448"/>
        <location filename="../src/GUI/gui.cpp" line="1509"/>
        <source>Moving time</source>
        <translation>Bewegungszeit</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="559"/>
        <source>Metric</source>
        <translation>Metrisch</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="564"/>
        <source>Imperial</source>
        <translation>Angloamerikanisch</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="570"/>
        <source>Nautical</source>
        <translation>Nautisch</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="578"/>
        <source>Decimal degrees (DD)</source>
        <translation>Dezimalgrad (DD)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="584"/>
        <source>Degrees and decimal minutes (DMM)</source>
        <translation>Grad und Dezimalminuten (DMM)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="591"/>
        <source>Degrees, minutes, seconds (DMS)</source>
        <translation>Grad, Minuten, Sekunden (DMS)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="598"/>
        <source>Fullscreen mode</source>
        <translation>Vollbildmodus</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="605"/>
        <source>Options...</source>
        <translation>Einstellungen …</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="612"/>
        <source>Next</source>
        <translation>Nächste</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="617"/>
        <source>Previous</source>
        <translation>Vorherige</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="622"/>
        <source>Last</source>
        <translation>Letzte</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="627"/>
        <source>First</source>
        <translation>Erste</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="665"/>
        <source>Open recent</source>
        <translation>Zuletzt geöffnete Dateien</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="696"/>
        <source>Layers</source>
        <translation>Schichten</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="722"/>
        <source>Position info</source>
        <translation>Positionsinfos</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="748"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="756"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="768"/>
        <source>Units</source>
        <translation>Einheiten</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="773"/>
        <source>Coordinates format</source>
        <translation>Koordinatenformate</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="904"/>
        <location filename="../src/GUI/gui.cpp" line="912"/>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="907"/>
        <location filename="../src/GUI/gui.cpp" line="916"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at %1.</source>
        <translation>GPXSee wird unter der GNU General Public License version 3 veröffentlicht. Mehr Informationen zu GPXSee auf der Homepage %1.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="945"/>
        <source>Append file</source>
        <translation>An Datei anhängen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="946"/>
        <source>Next/Previous</source>
        <translation>Nächste/Vorherige</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="948"/>
        <source>Toggle graph type</source>
        <translation>Graphtyp umschalten</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="950"/>
        <source>Toggle time type</source>
        <translation>Zeittyp umschalten</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="952"/>
        <source>Toggle position info</source>
        <translation>Positionsinfo umschalten</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="956"/>
        <source>Previous map</source>
        <translation>Vorherige Karte</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="957"/>
        <source>Zoom in</source>
        <translation>Hineinzoomen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="959"/>
        <source>Zoom out</source>
        <translation>Herauszoomen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="961"/>
        <source>Digital zoom</source>
        <translation>Digitaler Zoom</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="962"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="963"/>
        <source>Copy coordinates</source>
        <translation>Koordinaten kopieren</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="964"/>
        <source>Left Click</source>
        <translation>Links-Klick</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="984"/>
        <location filename="../src/GUI/gui.cpp" line="1002"/>
        <source>DEM directory:</source>
        <translation>DEM-Verzeichnis:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="986"/>
        <location filename="../src/GUI/gui.cpp" line="1004"/>
        <source>Styles directory:</source>
        <translation>Formatvorlagen-Verzeichnis:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="988"/>
        <location filename="../src/GUI/gui.cpp" line="1006"/>
        <source>Symbols directory:</source>
        <translation>Symbole-Verzeichnis:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1054"/>
        <source>Open directory</source>
        <translation>Verzeichnis öffnen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1126"/>
        <source>Error loading geo URI:</source>
        <translation>Fehler beim Laden der Geo-URI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1132"/>
        <location filename="../src/GUI/gui.cpp" line="1172"/>
        <location filename="../src/GUI/gui.cpp" line="1865"/>
        <location filename="../src/GUI/gui.cpp" line="1971"/>
        <source>Don&apos;t show again</source>
        <translation>Nicht wieder anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1433"/>
        <location filename="../src/GUI/gui.cpp" line="1491"/>
        <source>Areas</source>
        <translation>Flächen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1460"/>
        <location filename="../src/GUI/gui.cpp" line="1463"/>
        <location filename="../src/GUI/gui.cpp" line="1464"/>
        <source>Statistics</source>
        <translation>Statistiken</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1804"/>
        <location filename="../src/GUI/gui.cpp" line="1807"/>
        <source>Open map file</source>
        <translation>Kartendatei öffnen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1859"/>
        <location filename="../src/GUI/gui.cpp" line="1922"/>
        <location filename="../src/GUI/gui.cpp" line="1941"/>
        <location filename="../src/GUI/gui.cpp" line="1965"/>
        <source>Error loading map:</source>
        <translation>Fehler beim Laden der Kartendatei:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2005"/>
        <source>Select map directory</source>
        <translation>Kartenverzeichnis auswählen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2034"/>
        <source>Clear &quot;%1&quot; tile cache?</source>
        <translation>Kachel-Cache von &quot;%1&quot; bereinigen?</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2054"/>
        <source>DEM tiles download limit exceeded. If you really need data for such a huge area, download the files manually.</source>
        <translation>Das Download-Limit für die DEM-Kacheln wurde überschritten. Wenn Sie wirklich Daten für so ein großes Gebiet benötigen, laden Sie die Dateien manuell herunter.</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2057"/>
        <source>Download %n DEM tiles?</source>
        <translation>
            <numerusform>%n DEM-Kachel herunterladen?</numerusform>
            <numerusform>%n DEM-Kacheln herunterladen?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2070"/>
        <source>Could not download all required DEM files.</source>
        <translation>Es konnten nicht alle erforderlichen DEM-Dateien heruntergeladen werden.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2087"/>
        <source>No local DEM tiles found.</source>
        <translation>Keine lokalen DEM-Kacheln gefunden.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2101"/>
        <source>No files loaded</source>
        <translation>Keine Dateien geladen</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2105"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n Datei</numerusform>
            <numerusform>%n Dateien</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1437"/>
        <location filename="../src/GUI/gui.cpp" line="1439"/>
        <location filename="../src/GUI/gui.cpp" line="1496"/>
        <location filename="../src/GUI/gui.cpp" line="1498"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1429"/>
        <location filename="../src/GUI/gui.cpp" line="1487"/>
        <source>Routes</source>
        <translation>Routen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="939"/>
        <source>Next file</source>
        <translation>Nächste Datei</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="234"/>
        <source>Print...</source>
        <translation>Drucken …</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="240"/>
        <source>Export to PDF...</source>
        <translation>Als PDF exportieren …</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1431"/>
        <location filename="../src/GUI/gui.cpp" line="1489"/>
        <source>Waypoints</source>
        <translation>Wegpunkte</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="940"/>
        <source>Previous file</source>
        <translation>Vorherige Datei</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="441"/>
        <source>Route waypoints</source>
        <translation>Routen-Wegpunkte</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="662"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="690"/>
        <source>&amp;Map</source>
        <translation>&amp;Karte</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="705"/>
        <source>&amp;Graph</source>
        <translation>&amp;Graph</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="736"/>
        <source>&amp;POI</source>
        <translation>&amp;POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="717"/>
        <source>&amp;Data</source>
        <translation>D&amp;ata</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="477"/>
        <source>Download data DEM</source>
        <translation>DEM für Daten herunterladen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="483"/>
        <source>Download map DEM</source>
        <translation>DEM für die Karte herunterladen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="763"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="786"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="942"/>
        <source>First file</source>
        <translation>Erste Datei</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="944"/>
        <source>Last file</source>
        <translation>Letzte Datei</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="982"/>
        <location filename="../src/GUI/gui.cpp" line="1000"/>
        <source>CRS directory:</source>
        <translation>CRS-Verzeichnis:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="990"/>
        <location filename="../src/GUI/gui.cpp" line="1008"/>
        <source>Tile cache directory:</source>
        <translation>Kachel-Cache-Verzeichnis:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1164"/>
        <source>Error loading data file:</source>
        <translation>Fehler beim Laden der Datendatei:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1167"/>
        <location filename="../src/GUI/gui.cpp" line="1283"/>
        <source>Line: %1</source>
        <translation>Zeile: %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1280"/>
        <source>Error loading POI file:</source>
        <translation>Fehler beim Laden der POI-Datei:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1481"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1427"/>
        <location filename="../src/GUI/gui.cpp" line="1485"/>
        <source>Tracks</source>
        <translation>Strecken</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="216"/>
        <location filename="../src/GUI/gui.cpp" line="902"/>
        <source>About GPXSee</source>
        <translation>Über GPXSee</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="831"/>
        <source>Navigation</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="507"/>
        <location filename="../src/GUI/gui.cpp" line="1445"/>
        <location filename="../src/GUI/gui.cpp" line="1505"/>
        <source>Distance</source>
        <translation>Distanz</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="514"/>
        <location filename="../src/GUI/gui.cpp" line="764"/>
        <location filename="../src/GUI/gui.cpp" line="1447"/>
        <location filename="../src/GUI/gui.cpp" line="1507"/>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
</context>
<context>
    <name>GearRatioGraph</name>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="12"/>
        <location filename="../src/GUI/gearratiograph.h" line="17"/>
        <source>Gear ratio</source>
        <translation>Übersetzungsverhältnis</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="28"/>
        <source>Top</source>
        <translation>Mst</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="30"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="32"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="35"/>
        <source>Most used</source>
        <translation>Meist genutzt</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>GearRatioGraphItem</name>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="38"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="39"/>
        <source>Most used</source>
        <translation>Meist genutzt</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="139"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="142"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="123"/>
        <location filename="../src/GUI/graphview.cpp" line="131"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="67"/>
        <source>Data not available</source>
        <translation>Keine Daten verfügbar</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="126"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="134"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="148"/>
        <source>s</source>
        <translation>sek</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="151"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="154"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="86"/>
        <location filename="../src/GUI/graphview.cpp" line="191"/>
        <source>Distance</source>
        <translation>Distanz</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="193"/>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="12"/>
        <location filename="../src/GUI/heartrategraph.h" line="16"/>
        <source>Heart rate</source>
        <translation>Herzfrequenz</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="11"/>
        <source>bpm</source>
        <translation>bpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Ø</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Durchschnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>HeartRateGraphItem</name>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="19"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="20"/>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="22"/>
        <source>bpm</source>
        <translation>bpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="21"/>
        <source>Average</source>
        <translation>Durchschnitt</translation>
    </message>
</context>
<context>
    <name>MapItem</name>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="80"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="82"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
</context>
<context>
    <name>MapList</name>
    <message>
        <location filename="../src/map/maplist.cpp" line="158"/>
        <source>Supported files</source>
        <translation>Unterstützte Dateien</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="171"/>
        <source>MBTiles maps</source>
        <translation>MBTiles-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="166"/>
        <source>Garmin JNX maps</source>
        <translation>Garmin JNX-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="162"/>
        <source>AlpineQuest maps</source>
        <translation>AlpineQuest-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="164"/>
        <source>Garmin IMG maps</source>
        <translation>Garmin IMG-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="167"/>
        <source>BSB nautical charts</source>
        <translation>BSB-Seekarten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="163"/>
        <source>GEMF maps</source>
        <translation>GEMF-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="160"/>
        <source>Electronic Navigational Charts</source>
        <translation>ENC-Seekarten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="168"/>
        <source>KMZ maps</source>
        <translation>KMZ-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="169"/>
        <source>Mapsforge maps</source>
        <translation>Mapsforge-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="170"/>
        <source>OziExplorer maps</source>
        <translation>OziExplorer-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="172"/>
        <source>Orux maps</source>
        <translation>Orux-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="173"/>
        <source>QuickChart maps</source>
        <translation>QuickChart-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="175"/>
        <source>Osmdroid SQLite maps</source>
        <translation>Osmdroid SQLite-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="178"/>
        <source>TrekBuddy maps/atlases</source>
        <translation>TrekBuddy-Karten/Atlanten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="180"/>
        <source>GeoTIFF images</source>
        <translation>GeoTIFF-Bilder</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="184"/>
        <source>All files</source>
        <translation>Alle Dateien</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="174"/>
        <source>TwoNav maps</source>
        <translation>TwoNav-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="176"/>
        <source>Locus/OsmAnd/RMaps SQLite maps</source>
        <translation>Locus/OsmAnd/RMaps SQLite-Karten</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="181"/>
        <source>World-file georeferenced images</source>
        <translation>World-File georeferenzierte Bilder</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="183"/>
        <source>Online map sources</source>
        <translation>Online-Kartenquellen</translation>
    </message>
</context>
<context>
    <name>MotionInfoItem</name>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="87"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="90"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="93"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="100"/>
        <source>ft/min</source>
        <translation>ft/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="103"/>
        <source>m/min</source>
        <translation>m/min</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="187"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="210"/>
        <source>Base color:</source>
        <translation>Grundfarbe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="188"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="211"/>
        <source>Palette shift:</source>
        <translation>Palettenverschiebung:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="177"/>
        <source>Track width:</source>
        <translation>Streckenbreite:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="178"/>
        <source>Track style:</source>
        <translation>Streckenstil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="196"/>
        <source>Tracks</source>
        <translation>Strecken</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="180"/>
        <source>Route width:</source>
        <translation>Routenbreite:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="181"/>
        <source>Route style:</source>
        <translation>Routenstil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="201"/>
        <source>Routes</source>
        <translation>Routen</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="171"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="275"/>
        <source>Use anti-aliasing</source>
        <translation>Anti-Aliasing verwenden</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="281"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="287"/>
        <source>Line width:</source>
        <translation>Linienbreite:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="313"/>
        <source>Background color:</source>
        <translation>Hintergrundfarbe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="326"/>
        <source>Paths</source>
        <translation>Pfade</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="329"/>
        <source>Map</source>
        <translation>Karte</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="328"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="764"/>
        <source>Graphs</source>
        <translation>Graphen</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="78"/>
        <source>Select the proper coordinate reference system (CRS) of maps without a CRS definition (JNX, KMZ and World file maps).</source>
        <translation>Wählen Sie das richtige Koordinatenbezugssystem (CRS) von Karten, die kein CRS enthalten (JNX, KMZ und World-File Karten).</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="81"/>
        <source>Select the desired projection of vector maps (IMG, Mapsforge and ENC maps). The projection must be valid for the whole map area.</source>
        <translation>Wählen Sie die gewünschte Projektion von Vektorkarten (IMG, Mapsforge und ENC-Karten). Die Projektion muss im gesamten Kartenbereich gültig sein.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="86"/>
        <source>Standard</source>
        <translation>Standardmäßig</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="91"/>
        <source>Non-HiDPI maps are loaded as HiDPI maps. The map is sharp but map objects are small/hard to read.</source>
        <translation>Nicht-HiDPI-Karten werden als HiDPI-Karten geladen. Die Karte ist scharf, aber die Kartenobjekte sind klein / schwer zu lesen.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="93"/>
        <source>Non-HiDPI maps are loaded such as they are. Map objects have the expected size but the map is blurry.</source>
        <translation>Nicht-HiDPI-Karten werden so geladen, wie sie sind. Kartenobjekte haben die erwartete Größe, aber die Karte ist verschwommen.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="103"/>
        <source>Input</source>
        <translation>Eingabe</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="105"/>
        <source>Output</source>
        <translation>Ausgabe</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="112"/>
        <source>Input:</source>
        <translation>Eingabe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="115"/>
        <source>Output:</source>
        <translation>Ausgabe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="136"/>
        <source>Projection</source>
        <translation>Projektion</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="137"/>
        <source>HiDPI display mode</source>
        <translation>HiDPI-Anzeigemodus</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="194"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="199"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="204"/>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="195"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="200"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="205"/>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="243"/>
        <source>Waypoint color:</source>
        <translation>Wegpunkt-Farbe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="244"/>
        <source>Waypoint size:</source>
        <translation>Wegpunkt-Größe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="251"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="256"/>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="252"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="257"/>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="253"/>
        <source>Waypoints</source>
        <translation>Wegpunkte</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="246"/>
        <source>POI color:</source>
        <translation>POI-Farbe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="247"/>
        <source>POI size:</source>
        <translation>POI-Größe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="258"/>
        <source>POIs</source>
        <translation>POIs</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="282"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="288"/>
        <source>Slider color:</source>
        <translation>Schieber-Farbe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="327"/>
        <source>Points</source>
        <translation>Punkte</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="336"/>
        <source>Moving average window size</source>
        <translation>Fensterbreite des gleitenden Mittelwerts</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="361"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="371"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="495"/>
        <source>Elevation:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="362"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="372"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="494"/>
        <source>Speed:</source>
        <translation>Geschwindigkeit:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="363"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="373"/>
        <source>Heart rate:</source>
        <translation>Herzfrequenz:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="364"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="374"/>
        <source>Cadence:</source>
        <translation>Frequenz:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="365"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="375"/>
        <source>Power:</source>
        <translation>Leistung:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="360"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="378"/>
        <source>Smoothing</source>
        <translation>Glätten</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="354"/>
        <source>Eliminate GPS outliers</source>
        <translation>GPS-Ausreißer entfernen</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="391"/>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="405"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="408"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="411"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="415"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="791"/>
        <source>s</source>
        <translation>sek</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="538"/>
        <source>Minimal speed:</source>
        <translation>Minimale Geschwindigkeit:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="539"/>
        <source>Minimal duration:</source>
        <translation>Minimale Dauer:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="426"/>
        <source>Computed from distance/time</source>
        <translation>Berechnet aus Entfernung/Zeit</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="427"/>
        <source>Recorded by device</source>
        <translation>Aufgezeichnet von Gerät</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="432"/>
        <source>Show secondary speed</source>
        <translation>Sekundäre Geschwindigkeit anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="435"/>
        <source>GPS data</source>
        <translation>GPS-Daten</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="436"/>
        <source>DEM data</source>
        <translation>DEM-Daten</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="441"/>
        <source>Show secondary elevation</source>
        <translation>Sekundäre Höhe anzeigen</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="444"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="465"/>
        <source>Use segments</source>
        <translation>Segmente Verwenden</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="496"/>
        <source>Time zone:</source>
        <translation>Zeitzone:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="515"/>
        <source>Elevation</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="521"/>
        <source>Time zone</source>
        <translation>Zeitzone</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="551"/>
        <source>Filtering</source>
        <translation>Datenfilterung</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="550"/>
        <source>Sources</source>
        <translation>Datenquellen</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="552"/>
        <source>Pause detection</source>
        <translation>Pausenerkennung</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="574"/>
        <source>Radius:</source>
        <translation>Radius:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="510"/>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="147"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="154"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="160"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="228"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="235"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="273"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="639"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="183"/>
        <source>Area border width:</source>
        <translation>Flächen-Randbreite:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="184"/>
        <source>Area border style:</source>
        <translation>Flächen-Randstil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="185"/>
        <source>Area fill opacity:</source>
        <translation>Flächendeckkraft:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="207"/>
        <source>Areas</source>
        <translation>Flächen</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="309"/>
        <source>Info background</source>
        <translation>Text Hintergrund</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="315"/>
        <source>Crosshair color:</source>
        <translation>Fadenkreuz-Farbe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="316"/>
        <source>Info color:</source>
        <translation>Text-Farbe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="392"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="446"/>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="564"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="567"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="570"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="580"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="884"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="597"/>
        <source>Use HTTP authentication</source>
        <translation>HTTP-Authentifizierung verwenden</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="603"/>
        <source>Use $lat and $lon for NYY/SYY and EXXX/WXXX in the URL.</source>
        <translation>Verwenden Sie $lat und $lon für NYY/SYY und EXXX/WXXX in der URL.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="608"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="621"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="206"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="314"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="655"/>
        <source>Opacity:</source>
        <translation>Deckkraft:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="657"/>
        <source>Blur radius:</source>
        <translation>Unschärferadius:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="659"/>
        <source>Azimuth:</source>
        <translation>Azimut:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="660"/>
        <source>Altitude:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="661"/>
        <source>Z Factor:</source>
        <translation>Z-Faktor:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="666"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="696"/>
        <source>Source</source>
        <translation>Datenquelle</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="667"/>
        <source>Hillshading</source>
        <translation>Schummerung</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="685"/>
        <source>Plugin:</source>
        <translation>Plugin:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="703"/>
        <source>WYSIWYG</source>
        <translation>WYSIWYG</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="85"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="704"/>
        <source>High-Resolution</source>
        <translation>Hohe Auflösung</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="388"/>
        <source>Detect pauses</source>
        <translation>Pausen erkennen</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="537"/>
        <source>Detection:</source>
        <translation>Erkennung:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="656"/>
        <source>Lightening:</source>
        <translation>Aufhellung:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="709"/>
        <source>The printed area is approximately the display area. The map zoom level does not change.</source>
        <translation>Der Druckbereich entspricht ungefähr dem Anzeigebereich. Das Karten-Zoom ändert sich nicht.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="711"/>
        <source>The zoom level will be changed so that the whole content (tracks/waypoints) fits to the printed area and the map resolution is as close as possible to the print resolution.</source>
        <translation>Das Karten-Zoom ändert sich so, dass der ganze Inhalt (Strecken/Wegpunkte) in den Druckbereich passen und die Kartenauflösung so nah wie möglich an der Druckauflösung ist.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="727"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="729"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="731"/>
        <source>Distance</source>
        <translation>Distanz</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="733"/>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="735"/>
        <source>Moving time</source>
        <translation>Bewegungszeit</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="737"/>
        <source>Item count (&gt;1)</source>
        <translation>Elementanzahl (&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="752"/>
        <source>Separate graph page</source>
        <translation>Separate Seite für Graphen</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="762"/>
        <source>Print mode</source>
        <translation>Druckmodus</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="763"/>
        <source>Header</source>
        <translation>Kopfzeile</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="771"/>
        <source>Use OpenGL</source>
        <translation>OpenGL verwenden</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="773"/>
        <source>Enable HTTP/2</source>
        <translation>HTTP/2 verwenden</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="779"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="785"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="797"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="805"/>
        <source>Image cache size:</source>
        <translation>Bild-Cachegröße:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="799"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="807"/>
        <source>Connection timeout:</source>
        <translation>Verbindungs-Timeout:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="445"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="842"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="893"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="798"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="806"/>
        <source>DEM cache size:</source>
        <translation>DEM-Cachegröße:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="826"/>
        <source>Select the initial paths of the file open dialogues. Leave the field empty for the system default.</source>
        <translation>Wählen Sie die Anfangspfade der Dateiöffnungsdialoge aus. Für die Systemvorgabe lassen Sie das Feld leer.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="830"/>
        <source>Data:</source>
        <translation>Daten:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="831"/>
        <source>Maps:</source>
        <translation>Karten:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="832"/>
        <source>POI:</source>
        <translation>POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="843"/>
        <source>Initial paths</source>
        <translation>Anfangspfade</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="879"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="881"/>
        <source>Maps</source>
        <translation>Karten</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="883"/>
        <source>Data</source>
        <translation>Daten</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="886"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="889"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="891"/>
        <source>Print &amp; Export</source>
        <translation>Druck / Export</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="926"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>PDFExportDialog</name>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>PDF files</source>
        <translation>PDF-Dateien</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>All files</source>
        <translation>Alle Dateien</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="56"/>
        <source>Portrait</source>
        <translation>Hochformat</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="57"/>
        <source>Landscape</source>
        <translation>Querformat</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>in</source>
        <translation>in</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="73"/>
        <source>Page Setup</source>
        <translation>Seite einrichten</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="76"/>
        <source>Page size:</source>
        <translation>Seitengröße:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="77"/>
        <source>Resolution:</source>
        <translation>Druckauflösung:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="78"/>
        <source>Orientation:</source>
        <translation>Ausrichtung:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="79"/>
        <source>Margins:</source>
        <translation>Ränder:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="85"/>
        <source>File:</source>
        <translation>Ausgabedatei:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="92"/>
        <source>Output file</source>
        <translation>Ausgabedatei</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="99"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="119"/>
        <source>Export to PDF</source>
        <translation>In PDF exportieren</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="127"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
<context>
    <name>PNGExportDialog</name>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>PNG files</source>
        <translation>PNG-Dateien</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>All files</source>
        <translation>Alle Dateien</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="34"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="39"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="43"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="45"/>
        <source>Use anti-aliasing</source>
        <translation>Anti-Aliasing verwenden</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="49"/>
        <source>Image Setup</source>
        <translation>Bildeinstellungen</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="52"/>
        <source>Image width:</source>
        <translation>Bildbreite:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="53"/>
        <source>Image height:</source>
        <translation>Bildhöhe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="54"/>
        <source>Margins:</source>
        <translation>Ränder:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="61"/>
        <source>File:</source>
        <translation>Ausgabedatei:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="68"/>
        <source>Output file</source>
        <translation>Ausgabedatei</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="75"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="95"/>
        <source>Export to PNG</source>
        <translation>In PNG exportieren</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="103"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
<context>
    <name>PolygonItem</name>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="18"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="20"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="11"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="12"/>
        <location filename="../src/GUI/powergraph.h" line="16"/>
        <source>Power</source>
        <translation>Leistung</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Ø</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Durchschnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>PowerGraphItem</name>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="19"/>
        <location filename="../src/GUI/powergraphitem.cpp" line="21"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>Durchschnitt</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="16"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="18"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="20"/>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="21"/>
        <source>Distance</source>
        <translation>Distanz</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="32"/>
        <source>Links</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="38"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="108"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="109"/>
        <location filename="../src/GUI/scaleitem.cpp" line="112"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="111"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="114"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="115"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="15"/>
        <location filename="../src/GUI/speedgraph.h" line="18"/>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="152"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="39"/>
        <source>Average</source>
        <translation>Durchschnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="30"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="34"/>
        <source>Avg</source>
        <translation>Ø</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="36"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="41"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="44"/>
        <source>Pace</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="146"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="149"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
</context>
<context>
    <name>SpeedGraphItem</name>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="25"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="29"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="33"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="35"/>
        <source>Average</source>
        <translation>Durchschnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="37"/>
        <source>Pace</source>
        <translation>Tempo</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="12"/>
        <location filename="../src/GUI/temperaturegraph.h" line="16"/>
        <source>Temperature</source>
        <translation>Temperatur</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Ø</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="30"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="32"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="35"/>
        <source>Average</source>
        <translation>Durchschnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="112"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="116"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>TemperatureGraphItem</name>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="26"/>
        <source>Average</source>
        <translation>Durchschnitt</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="28"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="30"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="15"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="17"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="19"/>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="20"/>
        <source>Distance</source>
        <translation>Distanz</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="23"/>
        <source>Total time</source>
        <translation>Gesamtzeit</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="25"/>
        <source>Moving time</source>
        <translation>Bewegungszeit</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="28"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="40"/>
        <source>Links</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="46"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="26"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="27"/>
        <source>Coordinates</source>
        <translation>Koordinaten</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="34"/>
        <source>Elevation</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="38"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="43"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="47"/>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="50"/>
        <source>Symbol</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="55"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="58"/>
        <source>Phone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="68"/>
        <source>Links</source>
        <translation>Links</translation>
    </message>
</context>
</TS>
